==> igniteui-react-18.5.2-beta.0.tgz: package/esm2015/lib/igr-input.js <==
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { InputType_$type } from "./InputType";
import { InputInputmode_$type } from "./InputInputmode";
import { IgrComponentValueChangedEventArgs } from "./igr-component-value-changed-event-args";
import { IgrInputBase } from "./igr-input-base";
import { Input } from "./Input";
import { IgcInputComponent, defineComponents } from "igniteui-webcomponents";
import { ensureEnum, ensureBool } from "igniteui-react-core";
/**

*/
export class IgrInput extends IgrInputBase {
    createImplementation() {
        return new Input();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._change = null;
        this._change_wrapped = null;
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcInputComponent);
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("igc-input", {
            ref: this._getMainRef,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * The value of the control.
    */
    get value() {
        return this.i.an;
    }
    set value(v) {
        this.i.an = v;
    }
    /**
     * The type attribute of the control.
    */
    get type() {
        return this.i.ae;
    }
    set type(v) {
        this.i.ae = ensureEnum(InputType_$type, v);
    }
    /**
     * The input mode attribute of the control.
    */
    get inputmode() {
        return this.i.ad;
    }
    set inputmode(v) {
        this.i.ad = ensureEnum(InputInputmode_$type, v);
    }
    /**
     * The pattern attribute of the control.
    */
    get pattern() {
        return this.i.am;
    }
    set pattern(v) {
        this.i.am = v;
    }
    /**
     * The minimum string length required by the control.
    */
    get minLength() {
        return this.i.ah;
    }
    set minLength(v) {
        this.i.ah = +v;
    }
    /**
     * The maximum string length of the control.
    */
    get maxLength() {
        return this.i.ag;
    }
    set maxLength(v) {
        this.i.ag = +v;
    }
    /**
     * The min attribute of the control.
    */
    get min() {
        return this.i.al;
    }
    set min(v) {
        this.i.al = v;
    }
    /**
     * The max attribute of the control.
    */
    get max() {
        return this.i.ak;
    }
    set max(v) {
        this.i.ak = v;
    }
    /**
     * The step attribute of the control.
    */
    get step() {
        return this.i.ai;
    }
    set step(v) {
        this.i.ai = +v;
    }
    /**
     * The autofocus attribute of the control.
    */
    get autofocus() {
        return this.i.af;
    }
    set autofocus(v) {
        this.i.af = ensureBool(v);
    }
    /**
     * The autocomplete attribute of the control.
    */
    get autocomplete() {
        return this.i.aj;
    }
    set autocomplete(v) {
        this.i.aj = v;
    }
    /**
     * Selects all text within the input.
    
    */
    select() {
        this.i.ap();
    }
    /**
     * Increments the numeric value of the input by one or more steps.
    
    */
    stepUp(n) {
        this.i.ar(n);
    }
    /**
     * Decrements the numeric value of the input by one or more steps.
    
    */
    stepDown(n) {
        this.i.aq(n);
    }
    get change() {
        return this._change;
    }
    set change(ev) {
        if (this._change_wrapped !== null) {
            this.i.change = delegateRemove(this.i.change, this._change_wrapped);
            this._change_wrapped = null;
            this._change = null;
        }
        this._change = ev;
        this._change_wrapped = (o, e) => {
            let outerArgs = new IgrComponentValueChangedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeChange) {
                this.beforeChange(this, outerArgs);
            }
            if (this._change) {
                this._change(this, outerArgs);
            }
        };
        this.i.change = delegateCombine(this.i.change, this._change_wrapped);
        if (this.i.changeChanged) {
            this.i.changeChanged();
        }
        ;
    }
}

==> igniteui-react-18.6.1-beta.0.tgz: package/esm2015/lib/igr-input.js <==
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { InputType_$type } from "./InputType";
import { InputInputmode_$type } from "./InputInputmode";
import { IgrComponentValueChangedEventArgs } from "./igr-component-value-changed-event-args";
import { IgrInputBase } from "./igr-input-base";
import { Input } from "./Input";
import { IgcInputComponent, defineComponents } from "igniteui-webcomponents";
import { ensureEnum, ensureBool } from "igniteui-react-core";
/**

*/
export class IgrInput extends IgrInputBase {
    createImplementation() {
        return new Input();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._change = null;
        this._change_wrapped = null;
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcInputComponent);
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("igc-input", {
            ref: this._getMainRef,
            id: this.props.id,
            class: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * The value of the control.
    */
    get value() {
        return this.i.au;
    }
    set value(v) {
        this.i.au = v;
    }
    /**
     * The type attribute of the control.
    */
    get type() {
        return this.i.ai;
    }
    set type(v) {
        this.i.ai = ensureEnum(InputType_$type, v);
    }
    /**
     * The input mode attribute of the control.
    */
    get inputmode() {
        return this.i.ah;
    }
    set inputmode(v) {
        this.i.ah = ensureEnum(InputInputmode_$type, v);
    }
    /**
     * The pattern attribute of the control.
    */
    get pattern() {
        return this.i.at;
    }
    set pattern(v) {
        this.i.at = v;
    }
    /**
     * The minimum string length required by the control.
    */
    get minLength() {
        return this.i.ao;
    }
    set minLength(v) {
        this.i.ao = +v;
    }
    /**
     * The minlength attribute of the control.
     * @deprecated Use the `minLength` property instead.
    */
    get minlength() {
        return this.i.an;
    }
    set minlength(v) {
        this.i.an = +v;
    }
    /**
     * The maximum string length of the control.
    */
    get maxLength() {
        return this.i.am;
    }
    set maxLength(v) {
        this.i.am = +v;
    }
    /**
     * The maxlength attribute of the control.
     * @deprecated Use the `maxLength` property instead.
    */
    get maxlength() {
        return this.i.al;
    }
    set maxlength(v) {
        this.i.al = +v;
    }
    /**
     * The min attribute of the control.
    */
    get min() {
        return this.i.as;
    }
    set min(v) {
        this.i.as = v;
    }
    /**
     * The max attribute of the control.
    */
    get max() {
        return this.i.ar;
    }
    set max(v) {
        this.i.ar = v;
    }
    /**
     * The step attribute of the control.
    */
    get step() {
        return this.i.ap;
    }
    set step(v) {
        this.i.ap = +v;
    }
    /**
     * The autofocus attribute of the control.
    */
    get autofocus() {
        return this.i.aj;
    }
    set autofocus(v) {
        this.i.aj = ensureBool(v);
    }
    /**
     * The autocomplete attribute of the control.
    */
    get autocomplete() {
        return this.i.aq;
    }
    set autocomplete(v) {
        this.i.aq = v;
    }
    /**
     * Enables validation rules to be evaluated without restricting user input. This applies to the `maxLength` property for
     * string-type inputs or allows spin buttons to exceed the predefined `min/max` limits for number-type inputs.
    */
    get validateOnly() {
        return this.i.ak;
    }
    set validateOnly(v) {
        this.i.ak = ensureBool(v);
    }
    /**
     * Selects all text within the input.
    
    */
    select() {
        this.i.aw();
    }
    /**
     * Increments the numeric value of the input by one or more steps.
    
    */
    stepUp(n) {
        this.i.ay(n);
    }
    /**
     * Decrements the numeric value of the input by one or more steps.
    
    */
    stepDown(n) {
        this.i.ax(n);
    }
    get change() {
        return this._change;
    }
    set change(ev) {
        if (this._change_wrapped !== null) {
            this.i.change = delegateRemove(this.i.change, this._change_wrapped);
            this._change_wrapped = null;
            this._change = null;
        }
        this._change = ev;
        this._change_wrapped = (o, e) => {
            let outerArgs = new IgrComponentValueChangedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeChange) {
                this.beforeChange(this, outerArgs);
            }
            if (this._change) {
                this._change(this, outerArgs);
            }
        };
        this.i.change = delegateCombine(this.i.change, this._change_wrapped);
        if (this.i.changeChanged) {
            this.i.changeChanged();
        }
        ;
    }
}
